@@ -10,7 +10,7 @@ class Boost_df(object):
     def merge_df(self, origin_df: pd.DataFrame, df_list: list):
         df_ = pd.DataFrame()
         for df in df_list:
-            df_ = pd.merge(origin_df, df, on=['code', 'date'])
+            df_ = pd.merge(origin_df, df, on=['code', 'date'], how='left')
         return df_
 
 
